# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
import proto  # type: ignore

from google.ai.generativelanguage_v1beta.types import (
    cached_content as gag_cached_content,
)

__protobuf__ = proto.module(
    package="google.ai.generativelanguage.v1beta",
    manifest={
        "ListCachedContentsRequest",
        "ListCachedContentsResponse",
        "CreateCachedContentRequest",
        "GetCachedContentRequest",
        "UpdateCachedContentRequest",
        "DeleteCachedContentRequest",
    },
)


class ListCachedContentsRequest(proto.Message):
    r"""Request to list CachedContents.

    Attributes:
        page_size (int):
            Optional. The maximum number of cached
            contents to return. The service may return fewer
            than this value. If unspecified, some default
            (under maximum) number of items will be
            returned. The maximum value is 1000; values
            above 1000 will be coerced to 1000.
        page_token (str):
            Optional. A page token, received from a previous
            ``ListCachedContents`` call. Provide this to retrieve the
            subsequent page.

            When paginating, all other parameters provided to
            ``ListCachedContents`` must match the call that provided the
            page token.
    """

    page_size: int = proto.Field(
        proto.INT32,
        number=1,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class ListCachedContentsResponse(proto.Message):
    r"""Response with CachedContents list.

    Attributes:
        cached_contents (MutableSequence[google.ai.generativelanguage_v1beta.types.CachedContent]):
            List of cached contents.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    cached_contents: MutableSequence[
        gag_cached_content.CachedContent
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gag_cached_content.CachedContent,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class CreateCachedContentRequest(proto.Message):
    r"""Request to create CachedContent.

    Attributes:
        cached_content (google.ai.generativelanguage_v1beta.types.CachedContent):
            Required. The cached content to create.
    """

    cached_content: gag_cached_content.CachedContent = proto.Field(
        proto.MESSAGE,
        number=1,
        message=gag_cached_content.CachedContent,
    )


class GetCachedContentRequest(proto.Message):
    r"""Request to read CachedContent.

    Attributes:
        name (str):
            Required. The resource name referring to the content cache
            entry. Format: ``cachedContents/{id}``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateCachedContentRequest(proto.Message):
    r"""Request to update CachedContent.

    Attributes:
        cached_content (google.ai.generativelanguage_v1beta.types.CachedContent):
            Required. The content cache entry to update
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            The list of fields to update.
    """

    cached_content: gag_cached_content.CachedContent = proto.Field(
        proto.MESSAGE,
        number=1,
        message=gag_cached_content.CachedContent,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class DeleteCachedContentRequest(proto.Message):
    r"""Request to delete CachedContent.

    Attributes:
        name (str):
            Required. The resource name referring to the content cache
            entry Format: ``cachedContents/{id}``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
import proto  # type: ignore

from google.ai.generativelanguage_v1beta.types import permission as gag_permission

__protobuf__ = proto.module(
    package="google.ai.generativelanguage.v1beta",
    manifest={
        "CreatePermissionRequest",
        "GetPermissionRequest",
        "ListPermissionsRequest",
        "ListPermissionsResponse",
        "UpdatePermissionRequest",
        "DeletePermissionRequest",
        "TransferOwnershipRequest",
        "TransferOwnershipResponse",
    },
)


class CreatePermissionRequest(proto.Message):
    r"""Request to create a ``Permission``.

    Attributes:
        parent (str):
            Required. The parent resource of the ``Permission``.
            Formats: ``tunedModels/{tuned_model}`` ``corpora/{corpus}``
        permission (google.ai.generativelanguage_v1beta.types.Permission):
            Required. The permission to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    permission: gag_permission.Permission = proto.Field(
        proto.MESSAGE,
        number=2,
        message=gag_permission.Permission,
    )


class GetPermissionRequest(proto.Message):
    r"""Request for getting information about a specific ``Permission``.

    Attributes:
        name (str):
            Required. The resource name of the permission.

            Formats:
            ``tunedModels/{tuned_model}/permissions/{permission}``
            ``corpora/{corpus}/permissions/{permission}``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListPermissionsRequest(proto.Message):
    r"""Request for listing permissions.

    Attributes:
        parent (str):
            Required. The parent resource of the permissions. Formats:
            ``tunedModels/{tuned_model}`` ``corpora/{corpus}``
        page_size (int):
            Optional. The maximum number of ``Permission``\ s to return
            (per page). The service may return fewer permissions.

            If unspecified, at most 10 permissions will be returned.
            This method returns at most 1000 permissions per page, even
            if you pass larger page_size.
        page_token (str):
            Optional. A page token, received from a previous
            ``ListPermissions`` call.

            Provide the ``page_token`` returned by one request as an
            argument to the next request to retrieve the next page.

            When paginating, all other parameters provided to
            ``ListPermissions`` must match the call that provided the
            page token.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListPermissionsResponse(proto.Message):
    r"""Response from ``ListPermissions`` containing a paginated list of
    permissions.

    Attributes:
        permissions (MutableSequence[google.ai.generativelanguage_v1beta.types.Permission]):
            Returned permissions.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page.

            If this field is omitted, there are no more pages.
    """

    @property
    def raw_page(self):
        return self

    permissions: MutableSequence[gag_permission.Permission] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gag_permission.Permission,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class UpdatePermissionRequest(proto.Message):
    r"""Request to update the ``Permission``.

    Attributes:
        permission (google.ai.generativelanguage_v1beta.types.Permission):
            Required. The permission to update.

            The permission's ``name`` field is used to identify the
            permission to update.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to update. Accepted ones:

            -  role (``Permission.role`` field)
    """

    permission: gag_permission.Permission = proto.Field(
        proto.MESSAGE,
        number=1,
        message=gag_permission.Permission,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class DeletePermissionRequest(proto.Message):
    r"""Request to delete the ``Permission``.

    Attributes:
        name (str):
            Required. The resource name of the permission. Formats:
            ``tunedModels/{tuned_model}/permissions/{permission}``
            ``corpora/{corpus}/permissions/{permission}``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class TransferOwnershipRequest(proto.Message):
    r"""Request to transfer the ownership of the tuned model.

    Attributes:
        name (str):
            Required. The resource name of the tuned model to transfer
            ownership.

            Format: ``tunedModels/my-model-id``
        email_address (str):
            Required. The email address of the user to
            whom the tuned model is being transferred to.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    email_address: str = proto.Field(
        proto.STRING,
        number=2,
    )


class TransferOwnershipResponse(proto.Message):
    r"""Response from ``TransferOwnership``."""


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ai.generativelanguage.v1",
    manifest={
        "Model",
    },
)


class Model(proto.Message):
    r"""Information about a Generative Language Model.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Required. The resource name of the ``Model``. Refer to
            `Model
            variants <https://ai.google.dev/gemini-api/docs/models/gemini#model-variations>`__
            for all allowed values.

            Format: ``models/{model}`` with a ``{model}`` naming
            convention of:

            -  "{base_model_id}-{version}"

            Examples:

            -  ``models/gemini-1.5-flash-001``
        base_model_id (str):
            Required. The name of the base model, pass this to the
            generation request.

            Examples:

            -  ``gemini-1.5-flash``
        version (str):
            Required. The version number of the model.

            This represents the major version (``1.0`` or ``1.5``)
        display_name (str):
            The human-readable name of the model. E.g.
            "Gemini 1.5 Flash".
            The name can be up to 128 characters long and
            can consist of any UTF-8 characters.
        description (str):
            A short description of the model.
        input_token_limit (int):
            Maximum number of input tokens allowed for
            this model.
        output_token_limit (int):
            Maximum number of output tokens available for
            this model.
        supported_generation_methods (MutableSequence[str]):
            The model's supported generation methods.

            The corresponding API method names are defined as Pascal
            case strings, such as ``generateMessage`` and
            ``generateContent``.
        temperature (float):
            Controls the randomness of the output.

            Values can range over ``[0.0,max_temperature]``, inclusive.
            A higher value will produce responses that are more varied,
            while a value closer to ``0.0`` will typically result in
            less surprising responses from the model. This value
            specifies default to be used by the backend while making the
            call to the model.

            This field is a member of `oneof`_ ``_temperature``.
        max_temperature (float):
            The maximum temperature this model can use.

            This field is a member of `oneof`_ ``_max_temperature``.
        top_p (float):
            For `Nucleus
            sampling <https://ai.google.dev/gemini-api/docs/prompting-strategies#top-p>`__.

            Nucleus sampling considers the smallest set of tokens whose
            probability sum is at least ``top_p``. This value specifies
            default to be used by the backend while making the call to
            the model.

            This field is a member of `oneof`_ ``_top_p``.
        top_k (int):
            For Top-k sampling.

            Top-k sampling considers the set of ``top_k`` most probable
            tokens. This value specifies default to be used by the
            backend while making the call to the model. If empty,
            indicates the model doesn't use top-k sampling, and
            ``top_k`` isn't allowed as a generation parameter.

            This field is a member of `oneof`_ ``_top_k``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    base_model_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    version: str = proto.Field(
        proto.STRING,
        number=3,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=4,
    )
    description: str = proto.Field(
        proto.STRING,
        number=5,
    )
    input_token_limit: int = proto.Field(
        proto.INT32,
        number=6,
    )
    output_token_limit: int = proto.Field(
        proto.INT32,
        number=7,
    )
    supported_generation_methods: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=8,
    )
    temperature: float = proto.Field(
        proto.FLOAT,
        number=9,
        optional=True,
    )
    max_temperature: float = proto.Field(
        proto.FLOAT,
        number=13,
        optional=True,
    )
    top_p: float = proto.Field(
        proto.FLOAT,
        number=10,
        optional=True,
    )
    top_k: int = proto.Field(
        proto.INT32,
        number=11,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-

# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/consumer.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x19google/api/consumer.proto\x12\ngoogle.api"=\n\x11ProjectProperties\x12(\n\nproperties\x18\x01 \x03(\x0b\x32\x14.google.api.Property"\xac\x01\n\x08Property\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0e\x32!.google.api.Property.PropertyType\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t"L\n\x0cPropertyType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\t\n\x05INT64\x10\x01\x12\x08\n\x04\x42OOL\x10\x02\x12\n\n\x06STRING\x10\x03\x12\n\n\x06\x44OUBLE\x10\x04\x42h\n\x0e\x63om.google.apiB\rConsumerProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfigb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "google.api.consumer_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\016com.google.apiB\rConsumerProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig"
    _globals["_PROJECTPROPERTIES"]._serialized_start = 41
    _globals["_PROJECTPROPERTIES"]._serialized_end = 102
    _globals["_PROPERTY"]._serialized_start = 105
    _globals["_PROPERTY"]._serialized_end = 277
    _globals["_PROPERTY_PROPERTYTYPE"]._serialized_start = 201
    _globals["_PROPERTY_PROPERTYTYPE"]._serialized_end = 277
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
import proto  # type: ignore

from google.ai.generativelanguage_v1alpha.types import retriever

__protobuf__ = proto.module(
    package="google.ai.generativelanguage.v1alpha",
    manifest={
        "CreateCorpusRequest",
        "GetCorpusRequest",
        "UpdateCorpusRequest",
        "DeleteCorpusRequest",
        "ListCorporaRequest",
        "ListCorporaResponse",
        "QueryCorpusRequest",
        "QueryCorpusResponse",
        "RelevantChunk",
        "CreateDocumentRequest",
        "GetDocumentRequest",
        "UpdateDocumentRequest",
        "DeleteDocumentRequest",
        "ListDocumentsRequest",
        "ListDocumentsResponse",
        "QueryDocumentRequest",
        "QueryDocumentResponse",
        "CreateChunkRequest",
        "BatchCreateChunksRequest",
        "BatchCreateChunksResponse",
        "GetChunkRequest",
        "UpdateChunkRequest",
        "BatchUpdateChunksRequest",
        "BatchUpdateChunksResponse",
        "DeleteChunkRequest",
        "BatchDeleteChunksRequest",
        "ListChunksRequest",
        "ListChunksResponse",
    },
)


class CreateCorpusRequest(proto.Message):
    r"""Request to create a ``Corpus``.

    Attributes:
        corpus (google.ai.generativelanguage_v1alpha.types.Corpus):
            Required. The ``Corpus`` to create.
    """

    corpus: retriever.Corpus = proto.Field(
        proto.MESSAGE,
        number=1,
        message=retriever.Corpus,
    )


class GetCorpusRequest(proto.Message):
    r"""Request for getting information about a specific ``Corpus``.

    Attributes:
        name (str):
            Required. The name of the ``Corpus``. Example:
            ``corpora/my-corpus-123``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateCorpusRequest(proto.Message):
    r"""Request to update a ``Corpus``.

    Attributes:
        corpus (google.ai.generativelanguage_v1alpha.types.Corpus):
            Required. The ``Corpus`` to update.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to update. Currently, this only
            supports updating ``display_name``.
    """

    corpus: retriever.Corpus = proto.Field(
        proto.MESSAGE,
        number=1,
        message=retriever.Corpus,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class DeleteCorpusRequest(proto.Message):
    r"""Request to delete a ``Corpus``.

    Attributes:
        name (str):
            Required. The resource name of the ``Corpus``. Example:
            ``corpora/my-corpus-123``
        force (bool):
            Optional. If set to true, any ``Document``\ s and objects
            related to this ``Corpus`` will also be deleted.

            If false (the default), a ``FAILED_PRECONDITION`` error will
            be returned if ``Corpus`` contains any ``Document``\ s.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    force: bool = proto.Field(
        proto.BOOL,
        number=2,
    )


class ListCorporaRequest(proto.Message):
    r"""Request for listing ``Corpora``.

    Attributes:
        page_size (int):
            Optional. The maximum number of ``Corpora`` to return (per
            page). The service may return fewer ``Corpora``.

            If unspecified, at most 10 ``Corpora`` will be returned. The
            maximum size limit is 20 ``Corpora`` per page.
        page_token (str):
            Optional. A page token, received from a previous
            ``ListCorpora`` call.

            Provide the ``next_page_token`` returned in the response as
            an argument to the next request to retrieve the next page.

            When paginating, all other parameters provided to
            ``ListCorpora`` must match the call that provided the page
            token.
    """

    page_size: int = proto.Field(
        proto.INT32,
        number=1,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class ListCorporaResponse(proto.Message):
    r"""Response from ``ListCorpora`` containing a paginated list of
    ``Corpora``. The results are sorted by ascending
    ``corpus.create_time``.

    Attributes:
        corpora (MutableSequence[google.ai.generativelanguage_v1alpha.types.Corpus]):
            The returned corpora.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no more
            pages.
    """

    @property
    def raw_page(self):
        return self

    corpora: MutableSequence[retriever.Corpus] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=retriever.Corpus,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class QueryCorpusRequest(proto.Message):
    r"""Request for querying a ``Corpus``.

    Attributes:
        name (str):
            Required. The name of the ``Corpus`` to query. Example:
            ``corpora/my-corpus-123``
        query (str):
            Required. Query string to perform semantic
            search.
        metadata_filters (MutableSequence[google.ai.generativelanguage_v1alpha.types.MetadataFilter]):
            Optional. Filter for ``Chunk`` and ``Document`` metadata.
            Each ``MetadataFilter`` object should correspond to a unique
            key. Multiple ``MetadataFilter`` objects are joined by
            logical "AND"s.

            Example query at document level: (year >= 2020 OR year <
            2010) AND (genre = drama OR genre = action)

            ``MetadataFilter`` object list: metadata_filters = [ {key =
            "document.custom_metadata.year" conditions = [{int_value =
            2020, operation = GREATER_EQUAL}, {int_value = 2010,
            operation = LESS}]}, {key = "document.custom_metadata.year"
            conditions = [{int_value = 2020, operation = GREATER_EQUAL},
            {int_value = 2010, operation = LESS}]}, {key =
            "document.custom_metadata.genre" conditions = [{string_value
            = "drama", operation = EQUAL}, {string_value = "action",
            operation = EQUAL}]}]

            Example query at chunk level for a numeric range of values:
            (year > 2015 AND year <= 2020)

            ``MetadataFilter`` object list: metadata_filters = [ {key =
            "chunk.custom_metadata.year" conditions = [{int_value =
            2015, operation = GREATER}]}, {key =
            "chunk.custom_metadata.year" conditions = [{int_value =
            2020, operation = LESS_EQUAL}]}]

            Note: "AND"s for the same key are only supported for numeric
            values. String values only support "OR"s for the same key.
        results_count (int):
            Optional. The maximum number of ``Chunk``\ s to return. The
            service may return fewer ``Chunk``\ s.

            If unspecified, at most 10 ``Chunk``\ s will be returned.
            The maximum specified result count is 100.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    query: str = proto.Field(
        proto.STRING,
        number=2,
    )
    metadata_filters: MutableSequence[retriever.MetadataFilter] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=retriever.MetadataFilter,
    )
    results_count: int = proto.Field(
        proto.INT32,
        number=4,
    )


class QueryCorpusResponse(proto.Message):
    r"""Response from ``QueryCorpus`` containing a list of relevant chunks.

    Attributes:
        relevant_chunks (MutableSequence[google.ai.generativelanguage_v1alpha.types.RelevantChunk]):
            The relevant chunks.
    """

    relevant_chunks: MutableSequence["RelevantChunk"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="RelevantChunk",
    )


class RelevantChunk(proto.Message):
    r"""The information for a chunk relevant to a query.

    Attributes:
        chunk_relevance_score (float):
            ``Chunk`` relevance to the query.
        chunk (google.ai.generativelanguage_v1alpha.types.Chunk):
            ``Chunk`` associated with the query.
    """

    chunk_relevance_score: float = proto.Field(
        proto.FLOAT,
        number=1,
    )
    chunk: retriever.Chunk = proto.Field(
        proto.MESSAGE,
        number=2,
        message=retriever.Chunk,
    )


class CreateDocumentRequest(proto.Message):
    r"""Request to create a ``Document``.

    Attributes:
        parent (str):
            Required. The name of the ``Corpus`` where this ``Document``
            will be created. Example: ``corpora/my-corpus-123``
        document (google.ai.generativelanguage_v1alpha.types.Document):
            Required. The ``Document`` to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    document: retriever.Document = proto.Field(
        proto.MESSAGE,
        number=2,
        message=retriever.Document,
    )


class GetDocumentRequest(proto.Message):
    r"""Request for getting information about a specific ``Document``.

    Attributes:
        name (str):
            Required. The name of the ``Document`` to retrieve. Example:
            ``corpora/my-corpus-123/documents/the-doc-abc``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateDocumentRequest(proto.Message):
    r"""Request to update a ``Document``.

    Attributes:
        document (google.ai.generativelanguage_v1alpha.types.Document):
            Required. The ``Document`` to update.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to update. Currently, this only
            supports updating ``display_name`` and ``custom_metadata``.
    """

    document: retriever.Document = proto.Field(
        proto.MESSAGE,
        number=1,
        message=retriever.Document,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class DeleteDocumentRequest(proto.Message):
    r"""Request to delete a ``Document``.

    Attributes:
        name (str):
            Required. The resource name of the ``Document`` to delete.
            Example: ``corpora/my-corpus-123/documents/the-doc-abc``
        force (bool):
            Optional. If set to true, any ``Chunk``\ s and objects
            related to this ``Document`` will also be deleted.

            If false (the default), a ``FAILED_PRECONDITION`` error will
            be returned if ``Document`` contains any ``Chunk``\ s.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    force: bool = proto.Field(
        proto.BOOL,
        number=2,
    )


class ListDocumentsRequest(proto.Message):
    r"""Request for listing ``Document``\ s.

    Attributes:
        parent (str):
            Required. The name of the ``Corpus`` containing
            ``Document``\ s. Example: ``corpora/my-corpus-123``
        page_size (int):
            Optional. The maximum number of ``Document``\ s to return
            (per page). The service may return fewer ``Document``\ s.

            If unspecified, at most 10 ``Document``\ s will be returned.
            The maximum size limit is 20 ``Document``\ s per page.
        page_token (str):
            Optional. A page token, received from a previous
            ``ListDocuments`` call.

            Provide the ``next_page_token`` returned in the response as
            an argument to the next request to retrieve the next page.

            When paginating, all other parameters provided to
            ``ListDocuments`` must match the call that provided the page
            token.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListDocumentsResponse(proto.Message):
    r"""Response from ``ListDocuments`` containing a paginated list of
    ``Document``\ s. The ``Document``\ s are sorted by ascending
    ``document.create_time``.

    Attributes:
        documents (MutableSequence[google.ai.generativelanguage_v1alpha.types.Document]):
            The returned ``Document``\ s.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no more
            pages.
    """

    @property
    def raw_page(self):
        return self

    documents: MutableSequence[retriever.Document] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=retriever.Document,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class QueryDocumentRequest(proto.Message):
    r"""Request for querying a ``Document``.

    Attributes:
        name (str):
            Required. The name of the ``Document`` to query. Example:
            ``corpora/my-corpus-123/documents/the-doc-abc``
        query (str):
            Required. Query string to perform semantic
            search.
        results_count (int):
            Optional. The maximum number of ``Chunk``\ s to return. The
            service may return fewer ``Chunk``\ s.

            If unspecified, at most 10 ``Chunk``\ s will be returned.
            The maximum specified result count is 100.
        metadata_filters (MutableSequence[google.ai.generativelanguage_v1alpha.types.MetadataFilter]):
            Optional. Filter for ``Chunk`` metadata. Each
            ``MetadataFilter`` object should correspond to a unique key.
            Multiple ``MetadataFilter`` objects are joined by logical
            "AND"s.

            Note: ``Document``-level filtering is not supported for this
            request because a ``Document`` name is already specified.

            Example query: (year >= 2020 OR year < 2010) AND (genre =
            drama OR genre = action)

            ``MetadataFilter`` object list: metadata_filters = [ {key =
            "chunk.custom_metadata.year" conditions = [{int_value =
            2020, operation = GREATER_EQUAL}, {int_value = 2010,
            operation = LESS}}, {key = "chunk.custom_metadata.genre"
            conditions = [{string_value = "drama", operation = EQUAL},
            {string_value = "action", operation = EQUAL}}]

            Example query for a numeric range of values: (year > 2015
            AND year <= 2020)

            ``MetadataFilter`` object list: metadata_filters = [ {key =
            "chunk.custom_metadata.year" conditions = [{int_value =
            2015, operation = GREATER}]}, {key =
            "chunk.custom_metadata.year" conditions = [{int_value =
            2020, operation = LESS_EQUAL}]}]

            Note: "AND"s for the same key are only supported for numeric
            values. String values only support "OR"s for the same key.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    query: str = proto.Field(
        proto.STRING,
        number=2,
    )
    results_count: int = proto.Field(
        proto.INT32,
        number=3,
    )
    metadata_filters: MutableSequence[retriever.MetadataFilter] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message=retriever.MetadataFilter,
    )


class QueryDocumentResponse(proto.Message):
    r"""Response from ``QueryDocument`` containing a list of relevant
    chunks.

    Attributes:
        relevant_chunks (MutableSequence[google.ai.generativelanguage_v1alpha.types.RelevantChunk]):
            The returned relevant chunks.
    """

    relevant_chunks: MutableSequence["RelevantChunk"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="RelevantChunk",
    )


class CreateChunkRequest(proto.Message):
    r"""Request to create a ``Chunk``.

    Attributes:
        parent (str):
            Required. The name of the ``Document`` where this ``Chunk``
            will be created. Example:
            ``corpora/my-corpus-123/documents/the-doc-abc``
        chunk (google.ai.generativelanguage_v1alpha.types.Chunk):
            Required. The ``Chunk`` to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    chunk: retriever.Chunk = proto.Field(
        proto.MESSAGE,
        number=2,
        message=retriever.Chunk,
    )


class BatchCreateChunksRequest(proto.Message):
    r"""Request to batch create ``Chunk``\ s.

    Attributes:
        parent (str):
            Optional. The name of the ``Document`` where this batch of
            ``Chunk``\ s will be created. The parent field in every
            ``CreateChunkRequest`` must match this value. Example:
            ``corpora/my-corpus-123/documents/the-doc-abc``
        requests (MutableSequence[google.ai.generativelanguage_v1alpha.types.CreateChunkRequest]):
            Required. The request messages specifying the ``Chunk``\ s
            to create. A maximum of 100 ``Chunk``\ s can be created in a
            batch.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    requests: MutableSequence["CreateChunkRequest"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="CreateChunkRequest",
    )


class BatchCreateChunksResponse(proto.Message):
    r"""Response from ``BatchCreateChunks`` containing a list of created
    ``Chunk``\ s.

    Attributes:
        chunks (MutableSequence[google.ai.generativelanguage_v1alpha.types.Chunk]):
            ``Chunk``\ s created.
    """

    chunks: MutableSequence[retriever.Chunk] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=retriever.Chunk,
    )


class GetChunkRequest(proto.Message):
    r"""Request for getting information about a specific ``Chunk``.

    Attributes:
        name (str):
            Required. The name of the ``Chunk`` to retrieve. Example:
            ``corpora/my-corpus-123/documents/the-doc-abc/chunks/some-chunk``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateChunkRequest(proto.Message):
    r"""Request to update a ``Chunk``.

    Attributes:
        chunk (google.ai.generativelanguage_v1alpha.types.Chunk):
            Required. The ``Chunk`` to update.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to update. Currently, this only
            supports updating ``custom_metadata`` and ``data``.
    """

    chunk: retriever.Chunk = proto.Field(
        proto.MESSAGE,
        number=1,
        message=retriever.Chunk,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class BatchUpdateChunksRequest(proto.Message):
    r"""Request to batch update ``Chunk``\ s.

    Attributes:
        parent (str):
            Optional. The name of the ``Document`` containing the
            ``Chunk``\ s to update. The parent field in every
            ``UpdateChunkRequest`` must match this value. Example:
            ``corpora/my-corpus-123/documents/the-doc-abc``
        requests (MutableSequence[google.ai.generativelanguage_v1alpha.types.UpdateChunkRequest]):
            Required. The request messages specifying the ``Chunk``\ s
            to update. A maximum of 100 ``Chunk``\ s can be updated in a
            batch.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    requests: MutableSequence["UpdateChunkRequest"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="UpdateChunkRequest",
    )


class BatchUpdateChunksResponse(proto.Message):
    r"""Response from ``BatchUpdateChunks`` containing a list of updated
    ``Chunk``\ s.

    Attributes:
        chunks (MutableSequence[google.ai.generativelanguage_v1alpha.types.Chunk]):
            ``Chunk``\ s updated.
    """

    chunks: MutableSequence[retriever.Chunk] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=retriever.Chunk,
    )


class DeleteChunkRequest(proto.Message):
    r"""Request to delete a ``Chunk``.

    Attributes:
        name (str):
            Required. The resource name of the ``Chunk`` to delete.
            Example:
            ``corpora/my-corpus-123/documents/the-doc-abc/chunks/some-chunk``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class BatchDeleteChunksRequest(proto.Message):
    r"""Request to batch delete ``Chunk``\ s.

    Attributes:
        parent (str):
            Optional. The name of the ``Document`` containing the
            ``Chunk``\ s to delete. The parent field in every
            ``DeleteChunkRequest`` must match this value. Example:
            ``corpora/my-corpus-123/documents/the-doc-abc``
        requests (MutableSequence[google.ai.generativelanguage_v1alpha.types.DeleteChunkRequest]):
            Required. The request messages specifying the ``Chunk``\ s
            to delete.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    requests: MutableSequence["DeleteChunkRequest"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="DeleteChunkRequest",
    )


class ListChunksRequest(proto.Message):
    r"""Request for listing ``Chunk``\ s.

    Attributes:
        parent (str):
            Required. The name of the ``Document`` containing
            ``Chunk``\ s. Example:
            ``corpora/my-corpus-123/documents/the-doc-abc``
        page_size (int):
            Optional. The maximum number of ``Chunk``\ s to return (per
            page). The service may return fewer ``Chunk``\ s.

            If unspecified, at most 10 ``Chunk``\ s will be returned.
            The maximum size limit is 100 ``Chunk``\ s per page.
        page_token (str):
            Optional. A page token, received from a previous
            ``ListChunks`` call.

            Provide the ``next_page_token`` returned in the response as
            an argument to the next request to retrieve the next page.

            When paginating, all other parameters provided to
            ``ListChunks`` must match the call that provided the page
            token.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListChunksResponse(proto.Message):
    r"""Response from ``ListChunks`` containing a paginated list of
    ``Chunk``\ s. The ``Chunk``\ s are sorted by ascending
    ``chunk.create_time``.

    Attributes:
        chunks (MutableSequence[google.ai.generativelanguage_v1alpha.types.Chunk]):
            The returned ``Chunk``\ s.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no more
            pages.
    """

    @property
    def raw_page(self):
        return self

    chunks: MutableSequence[retriever.Chunk] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=retriever.Chunk,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ai.generativelanguage.v1beta",
    manifest={
        "Permission",
    },
)


class Permission(proto.Message):
    r"""Permission resource grants user, group or the rest of the
    world access to the PaLM API resource (e.g. a tuned model,
    corpus).

    A role is a collection of permitted operations that allows users
    to perform specific actions on PaLM API resources. To make them
    available to users, groups, or service accounts, you assign
    roles. When you assign a role, you grant permissions that the
    role contains.

    There are three concentric roles. Each role is a superset of the
    previous role's permitted operations:

    - reader can use the resource (e.g. tuned model, corpus) for
      inference
    - writer has reader's permissions and additionally can edit and
      share
    - owner has writer's permissions and additionally can delete


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Output only. Identifier. The permission name. A unique name
            will be generated on create. Examples:
            tunedModels/{tuned_model}/permissions/{permission}
            corpora/{corpus}/permissions/{permission} Output only.
        grantee_type (google.ai.generativelanguage_v1beta.types.Permission.GranteeType):
            Optional. Immutable. The type of the grantee.

            This field is a member of `oneof`_ ``_grantee_type``.
        email_address (str):
            Optional. Immutable. The email address of the
            user of group which this permission refers.
            Field is not set when permission's grantee type
            is EVERYONE.

            This field is a member of `oneof`_ ``_email_address``.
        role (google.ai.generativelanguage_v1beta.types.Permission.Role):
            Required. The role granted by this
            permission.

            This field is a member of `oneof`_ ``_role``.
    """

    class GranteeType(proto.Enum):
        r"""Defines types of the grantee of this permission.

        Values:
            GRANTEE_TYPE_UNSPECIFIED (0):
                The default value. This value is unused.
            USER (1):
                Represents a user. When set, you must provide email_address
                for the user.
            GROUP (2):
                Represents a group. When set, you must provide email_address
                for the group.
            EVERYONE (3):
                Represents access to everyone. No extra
                information is required.
        """
        GRANTEE_TYPE_UNSPECIFIED = 0
        USER = 1
        GROUP = 2
        EVERYONE = 3

    class Role(proto.Enum):
        r"""Defines the role granted by this permission.

        Values:
            ROLE_UNSPECIFIED (0):
                The default value. This value is unused.
            OWNER (1):
                Owner can use, update, share and delete the
                resource.
            WRITER (2):
                Writer can use, update and share the
                resource.
            READER (3):
                Reader can use the resource.
        """
        ROLE_UNSPECIFIED = 0
        OWNER = 1
        WRITER = 2
        READER = 3

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    grantee_type: GranteeType = proto.Field(
        proto.ENUM,
        number=2,
        optional=True,
        enum=GranteeType,
    )
    email_address: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    role: Role = proto.Field(
        proto.ENUM,
        number=4,
        optional=True,
        enum=Role,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .citation import CitationMetadata, CitationSource
from .discuss_service import (
    CountMessageTokensRequest,
    CountMessageTokensResponse,
    Example,
    GenerateMessageRequest,
    GenerateMessageResponse,
    Message,
    MessagePrompt,
)
from .model import Model
from .model_service import GetModelRequest, ListModelsRequest, ListModelsResponse
from .safety import (
    ContentFilter,
    HarmCategory,
    SafetyFeedback,
    SafetyRating,
    SafetySetting,
)
from .text_service import (
    Embedding,
    EmbedTextRequest,
    EmbedTextResponse,
    GenerateTextRequest,
    GenerateTextResponse,
    TextCompletion,
    TextPrompt,
)

__all__ = (
    "CitationMetadata",
    "CitationSource",
    "CountMessageTokensRequest",
    "CountMessageTokensResponse",
    "Example",
    "GenerateMessageRequest",
    "GenerateMessageResponse",
    "Message",
    "MessagePrompt",
    "Model",
    "GetModelRequest",
    "ListModelsRequest",
    "ListModelsResponse",
    "ContentFilter",
    "SafetyFeedback",
    "SafetyRating",
    "SafetySetting",
    "HarmCategory",
    "Embedding",
    "EmbedTextRequest",
    "EmbedTextResponse",
    "GenerateTextRequest",
    "GenerateTextResponse",
    "TextCompletion",
    "TextPrompt",
)
